# coding: utf-8
"""
 :copyright: (c) 2011 Philipp Benjamin Köppchen
 :license: GPLv3, see LICENSE for more details.
"""
from __future__ import absolute_import

from flaskext.openid import OpenID
from flask import request, session, render_template, redirect, g, url_for

from . import app, login_required
from ..model import User, Realm


oid = OpenID(app, '/tmp/openid')


@app.route("/users/login/", methods=["GET", "POST"])
@oid.loginhandler
def login():
    if g.user is not None:
        return redirect(oid.get_next_url())

    if request.method == 'POST':
        openid = request.form.get('openid')
        if openid:
            return oid.try_login(openid, ask_for=['nickname'])

    return render_template('user/login.html.jinja', next=oid.get_next_url(),
                                                    error=oid.fetch_error())


@oid.after_login
def create_or_login(resp):
    user = User.get_by_openid(resp.identity_url)

    if user is None:
        session['openid_candidate'] = resp.identity_url
        return redirect(url_for('register', nick=resp.nickname,
                                            next=oid.get_next_url() or ""))
    else:
        session['openid'] = resp.identity_url

    return redirect(oid.get_next_url())


@app.route("/users/logout/", methods=["GET", "POST"])
def logout():
    if request.method == 'POST':
        session['openid'] = None
        return redirect('/')
    else:
        return render_template('user/logout.html.jinja')


@app.route("/users/register/", methods=["GET", "POST"])
def register():
    if not 'openid_candidate' in session:
        abort(500)

    if request.method == 'POST':
        session["openid"] = session.pop("openid_candidate")

        user = User()
        user.openid = session["openid"]
        user.nick = request.form["nick"]
        user.save()

        return redirect(request.form["next"])
    else:
        return render_template('user/register.html.jinja',
                               next=request.args.get("next"),
                               nick=request.args.get("nick"))


@app.route("/profile/")
def show_profile():
    if not g.user:
        return redirect(url_for("login"))
    else:
        return redirect(url_for("show_user_profile", nick=g.user.nick))


@app.route("/profile/<string:nick>/")
def show_user_profile(nick):
    user = User.get_by_nick(nick)
    return render_template("user/profile.html.jinja",
                           user=user,
                           realms=user.get_realms())
